@@ -269,12 +269,18 @@ class LiveCDCopyBackend(backend.AnacondaBackend):
             "refresh=", "noddc", "xdriver=", "onlyvesa", "nvidia=", "dodmraid",
             "dmraid", "sabayonmce", "steambox", "quiet", "scandelay=",
             "doslowusb", "dokeymap", "keymap=", "radeon.modeset=",
-            "modeset=", "nomodeset", "domdadm"]
+            "modeset=", "nomodeset", "domdadm", "dohyperv", "dovirtio"]
 
         # use reference, yeah
         cmdline = self._sabayon_install.cmdline
         final_cmdline = []
 
+        if self._sabayon_install.is_hyperv() and ("dohyperv" not in cmdline):
+            cmdline.append("dohyperv")
+
+        if self._sabayon_install.is_kvm() and ("dovirtio" not in cmdline):
+            cmdline.append("dovirtio")
+
         # Sabayon MCE install -> MCE support
         if Entropy.is_sabayon_mce() and ("sabayonmce" not in cmdline):
             cmdline.append("sabayonmce")
